<template>
    <div class="map-container">
        <el-card class="farm-overview-container">
            <span class="overview-item" v-for="(value, key) in overView" :key="key">
                <i class="overview-item-icon" :class="`iconColor-${value.colorType} ${value.icon}`"></i>
                <span class="overview-item-con">{{ value.label }}: </span>
                <span class="overview-item-con">{{ value.value }}</span>
            </span>
            <!-- <span @click="setFitView">自适应</span> -->
        </el-card>
        <div class="map-content-container">
            <div id="container"></div>
            <div class="crew-card" id="crewCard" v-show="crewInfoShow">
                <div class="crew-card-title">
                    <div class="crew-code">
                        机组编码：{{ crewNumber }}
                        <!-- <el-button plain size="mini" round @click="handleDetail(crewNumber)"
              >详情</el-button
            > -->
                        <i class="el-icon-more" @click="handleDetail(crewNumber)"></i>
                    </div>
                    <i class="el-icon-close" @click="crewInfoShow = false"></i>
                    <i class="el-icon-caret-top"></i>
                </div>
                <div class="crew-card-content">
                    <el-row type="flex" style="flex-wrap: wrap; flex-direction: row" :gutter="16">
                        <el-col :span="24" v-for="(value, key) in crewInfo" :key="key">
                            <div class="current-crew-info">
                                <span class="crew-info-span">{{ value.label }}：</span>
                                {{ value.value }}
                                <span class="crew-info-span">{{
        value.unit
                                    }}</span>
                            </div>
                        </el-col>
                    </el-row>
                </div>
            </div>
        </div>
    </div>
</template>
<script>
// leaflet实现离线地图
import 'leaflet/dist/leaflet.css'
// 引入Leaflet对象 挂载到Vue上，便于全局使用，也可以单独页面中单独引用
import L from 'leaflet'
export default {
    name: 'map-model',
    data() {
        return {
            map: null,
            markers: [], //标点集合
            fanState: {}, //监听风机状态变化状态
            popups: [],
            overView: {
                setsNo: {
                    icon: 'icon-fengdianchang',
                    colorType: 'primary',
                    label: '装机台数',
                    value: null,
                },
                capacity: {
                    icon: 'icon-rongliangguanli',
                    colorType: 'primary',
                    label: '装机容量(MW)',
                    value: null,
                },
                emsFactoryWinspdAvg: {
                    icon: 'icon-fengsu1',
                    colorType: 'primary',
                    label: '全场平均风速（m/s）',
                    value: null,
                },
                factoryPowAct: {
                    icon: 'icon-yougonggongshuai',
                    colorType: 'primary',
                    label: '全场总有功功率(MW)',
                    value: null,
                },
                factoryDayEnergy: {
                    icon: 'icon-rifadianliang',
                    colorType: 'primary',
                    label: '全场当日发电量(MWh)',
                    value: null,
                },
                normal: {
                    icon: 'icon-fengdianta',
                    colorType: 'success',
                    label: '正常发电台数',
                    value: null,
                },
                emsFaultCount: {
                    icon: 'icon-fengdianta',
                    colorType: 'danger',
                    label: '故障台数',
                    value: null,
                },
                emsComerrCount: {
                    icon: 'icon-fengdianta',
                    colorType: 'info',
                    label: '通讯中断台数',
                    value: null,
                },
            },
            crewInfoShow: false,
            crewNumber: '',
            crewInfo: {
                // workModeSrc: {
                //     label: '工作状态',
                //     value: null,
                //     unit: null,
                // },
                winSpd: {
                    label: '瞬时风速',
                    value: null,
                    unit: 'm/s',
                },
                var_363: {
                    label: '风向',
                    value: null,
                    unit: '°',
                },
                powAct: {
                    label: '有功功率',
                    value: null,
                    unit: 'kW',
                },
                genSpeed: {
                    label: '发电机转速',
                    value: null,
                    unit: 'rpm',
                },
                dayEnergy: {
                    label: '今日发电量',
                    value: null,
                    unit: 'kWh',
                },
                evnTemp: {
                    label: '环境温度',
                    value: null,
                    unit: '℃',
                },
            },
            crewInfoArr: [
                // {
                //     label: '工作状态',
                //     value: null,
                //     unit: null,
                // },
                {
                    label: '瞬时风速',
                    value: null,
                    unit: 'm/s',
                },
                {
                    label: '风向',
                    value: null,
                    unit: '°',
                },
                {
                    label: '有功功率',
                    value: null,
                    unit: 'kW',
                },
                {
                    label: '发电机转速',
                    value: null,
                    unit: 'rpm',
                },
                {
                    label: '今日发电量',
                    value: null,
                    unit: 'kWh',
                },
                {
                    label: '环境温度',
                    value: null,
                    unit: '℃',
                },
            ],
            crewPoints: [],
            markerList: [],
            crewState: {},
            icon: require('../../assets/img/loading.gif'),
            accecptData: false,
            layerUrl: window.context.layer, // 地图瓦片根路径
            workModeSrc: [], //机组工作状态
            crewWorkMode: { // 当前选中风机工作状态
                value: '',
                name: ''
            }
        }
    },
    created() {
        //测试用的
        // setTimeout(() => {
        //     this.diffState()
        // }, 5000)
    },
    mounted() {
        this.initWorkMode()
        this.initWindFactory()
        this.accecptData = true
        this.initCrewPoints()
        this.$bus.$on('SCADAMsg', (data) => {
            if (this.accecptData) {
                this.changeData(data)
            }
        })
    },
    beforeDestroy() {
        // 切换页面 不再接收数据
        this.accecptData = false
    },
    methods: {
        initWindFactory() {
            this.$http.post('${cssc}/biz/base/windFactory/v1/getOne').then(
                (resp) => {
                    if (resp.data) {
                        // console.log(resp.data, 'dd')
                        this.overView.capacity.value = resp.data.capacity
                        this.overView.setsNo.value = resp.data.setsNo
                    }
                },
                (error) => {
                    reject(error)
                }
            )
        },
        changeData(data) {
            // console.log(data, 'data')
            // ------------头部总览
            // 正常发电台数
            let normal = 0
            for (let crew in data.fan) {
                if (
                    data.fan[crew].workModeSrc &&
                    data.fan[crew].workModeSrc.val === 32
                ) {
                    normal++
                }

                // 风机状态监听
                // 空字符是加初始数据
                // if (!this.fanState) {
                //     this.fanState[crew] !== data.fan[crew].workModeSrc.val
                // }


                // console.log(crew, this.fanState[crew], "crew, this.fanState[crew]")
                //diff数据是否变化
                if (
                    data.fan[crew].workModeSrc &&
                    this.fanState[crew].crewStatus !=
                    data.fan[crew].workModeSrc.val
                ) {
                    // console.log(
                    //     this.fanState[crew].crewStatus,
                    //     data.fan[crew].workModeSrc.val
                    // )

                    // 变化了 存入changeFaultData
                    this.fanState[crew].crewStatus =
                        data.fan[crew].workModeSrc.val
                    //参数：风机编号， 风机状态
                    this.diffState(crew, this.fanState[crew])
                }
            }

            // console.log(normal)
            // console.log(this.overView, 'overView')
            this.overView.normal.value = normal
            // 平均风速
            this.overView.emsFactoryWinspdAvg.value = data.wind
                .emsFactoryWinspdAvg
                ? data.wind.emsFactoryWinspdAvg.val
                : null
            // 全场总有功功率
            this.overView.factoryPowAct.value = data.wind.factoryPowAct
                ? data.wind.factoryPowAct.val
                : null
            // 全场当日发电量
            this.overView.factoryDayEnergy.value = data.wind.factoryDayEnergy
                ? data.wind.factoryDayEnergy.val
                : null
            // 故障台数
            this.overView.emsFaultCount.value = data.wind.emsFaultCount
                ? data.wind.emsFaultCount.val
                : null
            // 故障台数
            this.overView.emsComerrCount.value = data.wind.emsComerrCount
                ? data.wind.emsComerrCount.val
                : null

            //-------------机组信息

            // console.log(this.crewInfo, 'this.crewInfo')
            // console.log(this.crewNumber, 'cred')
            if (this.crewNumber && data.fan[this.crewNumber]) {
                this.crewWorkMode.name = this.bindWorkMode(data.fan[this.crewNumber].workModeSrc.val)
                this.crewWorkMode.value = data.fan[this.crewNumber].workModeSrc.val
                //瞬时风速
                // this.crewInfo.winSpd.value = data.fan[this.crewNumber].winSpd.val
                this.crewInfoArr[0].value = data.fan[this.crewNumber].winSpd.val
                // 瞬时风向
                // this.crewInfo.var_363.value = data.fan[this.crewNumber].var_363.val
                this.crewInfoArr[1].value =
                    data.fan[this.crewNumber].var_363.val
                // 有功功率
                // this.crewInfo.powAct.value = data.fan[this.crewNumber].powAct.val
                this.crewInfoArr[2].value = data.fan[this.crewNumber].powAct.val
                // 发电机转速
                // this.crewInfo.genSpeed.value = data.fan[this.crewNumber].genSpeed.val
                this.crewInfoArr[3].value =
                    data.fan[this.crewNumber].genSpeed.val
                // 今日发电量
                // this.crewInfo.dayEnergy.value = data.fan[this.crewNumber].dayEnergy.val
                this.crewInfoArr[4].value =
                    data.fan[this.crewNumber].dayEnergy.val
                // 环境温度
                // this.crewInfo.evnTemp.value = data.fan[this.crewNumber].evnTemp.val
                this.crewInfoArr[5].value =
                    data.fan[this.crewNumber].evnTemp.val

                //实时更新状态
                this.realTimeUpdate()
            }

            // diff状态 改变图片
            // this.formatPointData()
        },
        diffState(code, fanState) {
            //fancode风机编码， state风机状态
            let fanCode = code //变化的风机编号
            let fanName = fanState.fanName //变化的风机名称
            let state = fanState.crewStatus //变化风机的状态
            let option
            if (this.map.getZoom() < 9) {
                option = {
                    iconUrl: this.bindImg(state),
                    iconSize: [25, 30],
                    iconAnchor: [12.5, 30],
                }
                if (fanState.isFlagShip) {
                    option.shadowUrl = require('@/assets/img/flagShadow.png')
                    option.shadowSize = [15, 5]
                    option.shadowAnchor = [7.5, 3]
                }

            } else {
                option = {
                    iconUrl: this.bindImg(state),
                    iconSize: [50, 60],
                    iconAnchor: [25, 60],
                }
                if (fanState.isFlagShip) {
                    option.shadowUrl = require('@/assets/img/flagShadow.png')
                    option.shadowSize = [30, 10]
                    option.shadowAnchor = [15, 6]
                }
            }
            let icon = new L.Icon(option)

            //实时更新状态
            this.markers.forEach((item) => {
                if (item.options.title === fanName) {
                    item.setIcon(icon).update()
                }
            })
        },
        initCrewPoints() {
            let query = {
                sorter: [{ direction: 'ASC', property: 'fanCode' }],
            }
            this.$http.post('${cssc}/biz/base/fanInfo/v1/list', query).then(
                (resp) => {
                    this.crewPoints = []
                    let response = resp.data
                    response.forEach((el) => {
                        let arr = {
                            fanCode: el.fanCode,
                            fanName: el.fanName,
                            position: [
                                parseFloat(el.longitude),
                                parseFloat(el.latitude),
                            ],
                            state: 0,
                            isFlagShip: el.isFlagship,
                        }
                        this.crewPoints.push(arr)
                        this.fanState[el.fanCode] = {
                            crewStatus: 0,
                            fanName: el.fanName,
                            isFlagShip: el.isFlagship,
                        }
                    })
                    // console.log(this.fanState, 'this.fanState')
                    this.initMap()
                },
                (error) => {
                    reject(error)
                }
            )
        },
        initMap() {
            // let base = window.context.front
            // this.map = new AMap.Map('container', {
            //     center: [106.972, 28.7757],
            //     layers: [
            //         // 卫星
            //         new AMap.TileLayer.Satellite(),
            //         // 路网
            //         new AMap.TileLayer.RoadNet({opacity: 0.5}),
            //     ],
            //     zoom: 10,
            // })
            // this.initPointData()
            // this.map.setFitView()
            this.map = L.map('container', {
                zoominfoControl: true,
                zoomControl: false,
                zoomsliderControl: false,
                zoom: 5,
                center: [
                    this.crewPoints[0].position[1],
                    this.crewPoints[0].position[0],
                ],
                attributionControl: true,
            })
            // http://119.3.200.177:8090
            L.tileLayer(`${this.layerUrl}/{z}/{x}/{y}.png`, {
                maxZoom: 14,
                minZoom: 4,
                attribution: '',
            }).addTo(this.map)

            this.initPointData()

            this.map.on("zoomend", () => {
                if (this.map.getZoom() < 9) {
                    this.markers.forEach((item) => {
                        let options = item.options.icon.options
                        options.iconSize = [25, 30]
                        options.iconAnchor = [12.5, 30]
                        options.shadowSize = [15, 5]
                        options.shadowAnchor = [7.5, 3]
                        let icon = new L.Icon(options)
                        item.setIcon(icon).update()
                    })
                } else {
                    this.markers.forEach((item) => {
                        let options = item.options.icon.options
                        options.iconSize = [50, 60]
                        options.iconAnchor = [25, 60]
                        options.shadowSize = [30, 10]
                        options.shadowAnchor = [15, 6]
                        let icon = new L.Icon(options)
                        item.setIcon(icon).update()
                    })
                }
            })


        },
        bindImg(state) {
            if (state) {
                if (state == 8) {
                    return require('@/assets/img/crew-white.png')
                } else if (state == 1) {
                    return require('@/assets/img/crew-white.png')
                } else if (state == 2) {
                    return require('@/assets/img/crew-red.png')
                } else if (state == 4) {
                    return require('@/assets/img/crew-blue2.png')
                } else if (state == 16) {
                    return require('@/assets/img/crew-blue.gif')
                } else if (state == 32) {
                    return require('@/assets/img/crew-green.gif')
                } else if (state == 64) {
                    return require('@/assets/img/crew-orange.png')
                }
            } else {
                return require('@/assets/img/crew-gray.png')
            }
        },
        initPointData() {
            //设置ICON相关配置
            let base = 'http://cqhuan.top:8081/fvue'
            this.crewPoints.forEach((crew) => {
                crew.position = [crew.position[1], crew.position[0]]
                let option = {
                    iconUrl: this.bindImg(crew.state),
                    iconSize: [25, 30],
                    iconAnchor: [12.5, 30],
                }
                if (crew.isFlagShip) {
                    option.shadowUrl = require('@/assets/img/flagShadow.png')
                    option.shadowSize = [15, 5]
                    option.shadowAnchor = [7.5, 3]
                }

                let Icon = new L.Icon(option)
                // console.log(crew.position)
                let popup = L.popup()
                    .setLatLng(crew.position)
                    .setContent(
                        // 机组编码: ${crew.fanCode}
                        `<div class="popup">
                        <div class="popup-title">
                            机组名称: ${crew.fanName}
                        </div>
                        <div class="popup-content popup-content-workMode popup-content-${this.crewWorkMode.value}">
                            ${this.crewWorkMode.name}
                        </div>
                        <div class="popup-content">
                            ${this.crewInfoArr.map((item) => {
                            return `
                                <div class="popup-content-item">
                                    ${item.label}:
                                <span class="popup-color">
                                    ${item.value ? item.value : ''} 
                                </span>
                                ${item.unit ? item.unit : ''}
                                </div>`
                        })
                            .join('')}
                        </div>
                        <div class="detile" id="detile">
                            <span>详情</span>
                            <i class="el-icon-d-arrow-right"></i>
                        </div>
                    </div>`)
                // .openOn(this.map)
                this.popups.push(popup)

                let markerKey = 'markers_' + crew.fanCode
                markerKey = L.marker(crew.position, {
                    icon: Icon,
                    title: crew.fanName,
                    //title: crew.fanCode,
                })
                    .addTo(this.map)
                    .bindPopup(popup)
                    .on('popupopen', (e) => {
                        this.handleShowCrewInfo(e)
                    })
                this.markers.push(markerKey)
            })

            let length = this.crewPoints.length - 1
            let polygon = L.rectangle(
                [this.crewPoints[0].position, this.crewPoints[length].position],
                { color: 'rgba(0,0,0,0)', weight: 0 }
            ).addTo(this.map)
            //定位合适位置
            this.map.flyToBounds(polygon.getBounds())

            //this.crewState = {}
            // this.markerList = []

            // let markerContent1 = `<div class="custom-content-marker">
            //               <img src="${base}/img/crew-white.gif">
            //           </div>`
            // let markerContent2 = `<div class="custom-content-marker">
            //               <img src="/public/img/crew-white.png">
            //           </div>`

            // this.crewPoints.forEach(crew => {
            //   // var infoWindowContent = `<span>机组编号：${crew[2]}；经度：${crew[0]};纬度：${crew[1]}</span>`
            //   let marker = new AMap.Marker({
            //     // icon: require('../../assets/img/crew.gif'),
            //     position: crew.position,
            //     // 将 html 传给 content
            //     content: crew.state ? markerContent1 : markerContent2,
            //     map: this.map,
            //     title: crew.fanCode
            //   })
            //   this.crewState[crew.fanCode] = crew.state
            //   marker.crew = crew
            //   marker.on('click', this.handleShowCrewInfo)
            //   marker.emit('click', {target: marker})

            //   this.crewPoints.marker = marker

            //   this.markerList.push(marker)
            // })
            // function handleShowCrewInfo(e) {
            //   console.log(e.target)
            // }
            // // this.map.remove(this.markerList)
            // this.map.add(this.markerList)
            // this.map.setFitView()
        },
        //实时更新弹出层
        realTimeUpdate() {
            let popup = `
            <div class="popup">
                <div class="popup-title">
                    机组编码: ${this.fanState[this.crewNumber].fanName}
                </div>
                <div class="popup-content popup-content-workMode popup-content-${this.crewWorkMode.value}">${this.crewWorkMode.name}</div>
                <div class="popup-content">
                    ${this.crewInfoArr
                    .map((item) => {
                        return `
                        <div class="popup-content-item">
                            ${item.label}:
                            <span class="popup-color">
                                ${item.value ? item.value : ''} 
                            </span>
                            ${item.unit ? item.unit : ''}
                        </div>`
                    })
                    .join('')}
                </div>
                <div class="detile" id="detile">
                    <span>详情</span>
                    <i class="el-icon-d-arrow-right"></i>
                </div>
            </div>
            `
            this.popups.forEach((item) => {
                let fanName = item._source.options.title
                if (this.fanState[this.crewNumber].fanName === fanName) {
                    item.setContent(popup).update()
                }
            })
            //重新渲染之后需要重新绑定事件
            this.getDomDetile()
        },
        //获取详情按钮并绑定事件
        getDomDetile() {
            this.$nextTick(() => {
                let btnDetile = document.getElementById('detile')
                if (btnDetile) {
                    btnDetile.onclick = () => {
                        this.handleDetail(this.crewNumber)
                    }
                }
            })
        },
        handleShowCrewInfo(e) {
            let fanName = e.target.options.title
            let i = this.crewPoints.findIndex(item => {
                return item.fanName == fanName
            })
            this.crewNumber = this.crewPoints[i].fanCode
            //详情跳转
            this.getDomDetile()
            // this.crewNumber = e.target.crew.fanCode
            // if (!this.crewInfoShow) {
            //   this.crewInfoShow = true
            // }
            // let dom = document.querySelector('#crewCard')
            // console.log(dom, 'dom')
            // if (dom) {
            //   let top = e.containerPoint.y + 'px'
            //   let left = e.containerPoint.x + 'px'
            //   dom.style.setProperty('top', top, 'important')
            //   dom.style.setProperty('left', left, 'important')
            // }
        },
        setFitView() {
            this.map.setFitView()
        },
        handleDetail(crewNumber) {
            // this.$bus.$emit('changeTab', {
            //   from: 'MapModel',
            //   to: 'CrewOverview',
            //   id: crewNumber
            // })
            this.$router.push({
                path: `/frontPlat/CrewOverview/${crewNumber}`,
            })
        },
        initWorkMode() {
            let params = {
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'type',
                        relation: 'AND',
                        value: 'workMode',
                    },
                ],
            }
            this.$http
                .post('${cssc}/biz/scada/scadaFault/v1/query', params)
                .then(
                    (resp) => {
                        if (resp.data) {
                            this.workModeSrc = resp.data.rows
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
        },
        bindWorkMode(wordModeVal) {
            let name = ""
            if (wordModeVal) {
                this.workModeSrc.forEach(mode => {
                    if (mode.code == wordModeVal) {
                        name = mode.name
                    }
                })
            }
            return name
        },
    },
}
</script>
<style>
.custom-content-marker {
    position: relative;
    width: 40px;
    height: 60px;
}

.custom-content-marker img {
    width: 100%;
    height: 100%;
}
</style>
<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.map-container {
    position: relative;
    height: 100%;
    color: $--color-text;
}

.farm-overview-container {
    // width: 640px;
    // height: 350px;
    line-height: 40px;
    position: absolute;
    right: 10px;
    top: 10px;
    z-index: 999;
    color: $--color-text;
    background-color: rgba(4, 20, 43, 0.7);

    .overview-item {
        // margin-right: 20px;
        // width: 280px;
    }

    .overview-item-con {
        font-size: 1rem !important;
    }

    .overview-item-icon {
        font-size: 1.25rem !important;
        padding-right: 8px;
        vertical-align: middle;
        margin-top: -3px;
    }

    .iconColor-primary {
        color: $--color-primary;
    }

    .iconColor-success {
        color: $--color-success;
    }

    .iconColor-danger {
        color: $--color-danger;
    }

    .iconColor-warning {
        color: $--color-warning;
    }

    .iconColor-info {
        color: $--color-info;
    }

    /deep/ .el-card__body {
        padding: 10px;
        display: flex;
        flex-direction: column;
    }
}

.map-content-container {
    width: 100%;
    border-radius: 4px;
    height: calc(100% - 10px);
    position: relative;
    overflow: hidden;

    #container {
        width: 100%;
        height: 100%;
    }

    .crew-card {
        display: flex;
        flex-direction: column;
        min-width: 0;
        word-wrap: break-word;
        // background-color: rgba($--color-primary, 0.8);
        background-color: rgba(4, 20, 43, 0.9);
        background-clip: border-box;
        border-radius: 0.25rem;
        width: 16rem;
        border-width: 0;
        border-radius: 0.4rem;
        box-shadow: 0 2px 6px 0 rgba(55, 85, 59, 0.8);
        position: absolute;
        top: 1rem;
        left: 1rem;
        -ms-flex: 1 1 auto;
        flex: 1 1 auto;
        color: #fff;
        z-index: 999;
        transform: translate(-50%, 3px);
    }

    .crew-card-title {
        border-radius: 0.25rem;
        padding: 0.75rem 0.65rem;
        // background: $--color-primary;
        background: rgba(4, 20, 43, 0.5);
        display: flex;
        justify-content: space-between;
        align-items: center;
        position: relative;

        .el-icon-caret-top {
            position: absolute;
            top: -12px;
            left: 50%;
            transform: translateX(-50%);
            font-size: 18px;
            color: #333;
        }

        .el-icon-close {
            cursor: pointer;
            padding: 6px;
        }
    }

    .crew-card-content {
        padding: 10px 16px;
        background: #444;
    }

    .current-crew-info {
        margin: 4px 0;

        .crew-info-span {
            color: $--color-text;
        }
    }

    .crew-code {
        font-size: 14px;
    }
}

.content-window-card {
    position: relative;
    width: 23rem;
    padding: 0.75rem 0 0 1.25rem;
    box-shadow: none;
    bottom: 0;
    left: 0;
}

/deep/ .leaflet-popup .leaflet-popup-content-wrapper {
    background-color: rgba(37, 180, 190, 0.5);
}

/deep/ .map-content-container .leaflet-container a.leaflet-popup-close-button:hover {
    color: #333;
}

/deep/ .map-content-container .leaflet-container a.leaflet-popup-close-button {
    color: #fff;
}

.el-icon-more {
    margin-left: 10px;
    font-size: 16px;
    color: $--color-text;
    cursor: pointer;

    &:hover {
        color: $--light-active-border;
    }
}

/deep/ .leaflet-pane .leaflet-popup .leaflet-popup-content-wrapper {
    background: rgba(4, 20, 43, 0.7);
    color: #fff;
}

/deep/ .popup {
    font-size: 14px;
    position: relative;
}

/deep/ .popup-title {
    height: 30px;
    font-size: 16px;
    color: $--color-text;
    line-height: 30px;
}

/deep/ .popup-content {
    display: flex;
    flex-direction: column;
}

/deep/ .popup-content-item {
    margin: 5px 0;
}

/deep/ .popup-color {
    color: $--color-text;
    margin: 0 3px;
}

/deep/ .detile {
    position: absolute;
    right: -15px;
    bottom: -10px;

    &:hover {
        color: $--color-text;
        cursor: pointer;
    }
}

/deep/ .popup-content-workMode {
    font-size: 16px;
    font-weight: bold;
}

/deep/ .popup-content- {
    color: #819da7
}

/deep/ .popup-content-1 {
    color: #ececec
}

/deep/ .popup-content-2 {
    color: #d32c49
}

/deep/ .popup-content-4 {
    color: #2b94de
}

/deep/ .popup-content-8 {
    color: #ececec
}

/deep/ .popup-content-16 {
    color: #1572d2
}

/deep/ .popup-content-32 {
    color: #06b32c
}

/deep/ .popup-content-64 {
    color: #e88f02
}

// /deep/ .leaflet-popup-tip {
//   background-color: rgba(4, 20, 43, 0.7)
// }
</style>
